@@ -279,8 +279,6 @@ impl_Bonobo_Canvas_Component_update (PortableServer_Servant     servant,
 	return cuta;
 }
 
-static GdkGC *the_gc;
-
 static void
 impl_Bonobo_Canvas_Component_realize (PortableServer_Servant  servant,
 				      const CORBA_char       *window,
@@ -297,7 +295,6 @@ impl_Bonobo_Canvas_Component_realize (PortableServer_Servant  servant,
 		return;
 	}
 
-	the_gc = gdk_gc_new (gdk_window);
 	item->canvas->layout.bin_window = gdk_window;
 	ICLASS (item)->realize (item);
 }
@@ -943,7 +940,7 @@ typedef struct {
 
 static GType root_item_hack_get_type (void);
 #define ROOT_ITEM_HACK_TYPE (root_item_hack_get_type ())
-#define ROOT_ITEM_HACK(obj) (GTK_CHECK_CAST((obj), ROOT_ITEM_HACK_TYPE, RootItemHack))
+#define ROOT_ITEM_HACK(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), ROOT_ITEM_HACK_TYPE, RootItemHack))
 
 static void
 rih_dispose (GObject *obj)
@@ -999,7 +996,7 @@ rih_class_init (GObjectClass *klass)
 static GType
 root_item_hack_get_type (void)
 {
-	static GtkType type = 0;
+	static GType type = 0;
 
 	if (!type) {
 		GTypeInfo info = {
